==> nextcloud-app-mail-5.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/az.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Vacib",
    "Work" : "İş",
    "Personal" : "Şəxsi",
    "Mail" : "Məktub",
    "Save" : "Saxla",
    "Connect" : "Qoşul",
    "Name" : "Ad",
    "Password" : "Şifrə",
    "None" : "Heç bir",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "SMTP Şifrəsi",
    "Signature" : "İmza",
    "Cancel" : "Dayandır",
    "General" : "Ümumi",
    "Archive" : "Arxiv",
    "Delete" : "Sil",
    "Search" : "Axtarış",
    "Send" : "Göndər",
    "Refresh" : "Yenilə",
    "Subject" : "Mövzu",
    "Enter a date" : "Tarixi əlavə edin",
    "Choose" : "Seç",
    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
    "Confirm" : "Təsdiq edin",
    "Favorite" : "İstəkli",
    "Read" : "Oxu",
    "Back" : "Geri",
    "Description" : "Açıqlanma",
    "Create" : "Yarat",
    "Select" : "Select",
    "Comment" : "Komentariya",
    "Accept" : "Qəbul et",
    "Decline" : "İmtina",
    "Remove" : "Sil",
    "Other" : "Digər",
    "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
    "Move" : "Move",
    "Quota" : "Norma",
    "Saving" : "Saxlanılır",
    "Mark all as read" : "Hamısını oxunulmuş kimi qeydə al",
    "Rename" : "Adı dəyiş",
    "Clear cache" : "Keşi təmizlə",
    "Reply" : "Cavab",
    "Add" : "Əlavə etmək",
    "Close" : "Bağla",
    "Date" : "Date",
    "Tags" : "Işarələr",
    "Not found" : "Tapılmadı",
    "Actions" : "İşlər",
    "Priority" : "Prioritet",
    "Reset" : "Sıfırla",
    "Client ID" : "Müştəri İD-s",
    "Client secret" : "Müxtəri sirri",
    "User" : "User",
    "Host" : "Şəbəkədə ünvan",
    "Port" : "Port",
    "Valid until" : "Vaxtadək keçərlidir",
    "Certificate" : "Sertifikat",
    "All" : "Hamısı",
    "Drafts" : "Qaralamalar",
    "Favorites" : "Sevimlilər",
    "Inbox" : "Gələn qutusu",
    "Junk" : "Önəmsiz",
    "Sent" : "Göndərildi",
    "Trash" : "Zibil",
    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.1.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/az.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Vacib",
    "Work" : "İş",
    "Personal" : "Şəxsi",
    "Mail" : "Məktub",
    "Save" : "Saxla",
    "Connect" : "Qoşul",
    "Name" : "Ad",
    "Password" : "Şifrə",
    "None" : "Heç bir",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "SMTP Şifrəsi",
    "Signature" : "İmza",
    "Cancel" : "Dayandır",
    "General" : "Ümumi",
    "Archive" : "Arxiv",
    "Delete" : "Sil",
    "Search" : "Axtarış",
    "Send" : "Göndər",
    "Refresh" : "Yenilə",
    "Subject" : "Mövzu",
    "Enter a date" : "Tarixi əlavə edin",
    "Choose" : "Seç",
    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
    "Confirm" : "Təsdiq edin",
    "Favorite" : "İstəkli",
    "Read" : "Oxu",
    "Back" : "Geri",
    "Description" : "Açıqlanma",
    "Create" : "Yarat",
    "Select" : "Select",
    "Comment" : "Komentariya",
    "Accept" : "Qəbul et",
    "Decline" : "İmtina",
    "Remove" : "Sil",
    "Other" : "Digər",
    "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
    "Move" : "Move",
    "Quota" : "Norma",
    "Saving" : "Saxlanılır",
    "Mark all as read" : "Hamısını oxunulmuş kimi qeydə al",
    "Rename" : "Adı dəyiş",
    "Clear cache" : "Keşi təmizlə",
    "Reply" : "Cavab",
    "Add" : "Əlavə etmək",
    "Close" : "Bağla",
    "Date" : "Date",
    "Tags" : "Işarələr",
    "Not found" : "Tapılmadı",
    "Priority" : "Prioritet",
    "Reset" : "Sıfırla",
    "Client ID" : "Müştəri İD-s",
    "Client secret" : "Müxtəri sirri",
    "User" : "User",
    "Host" : "Şəbəkədə ünvan",
    "Port" : "Port",
    "Valid until" : "Vaxtadək keçərlidir",
    "Certificate" : "Sertifikat",
    "All" : "Hamısı",
    "Drafts" : "Qaralamalar",
    "Favorites" : "Sevimlilər",
    "Inbox" : "Gələn qutusu",
    "Junk" : "Önəmsiz",
    "Sent" : "Göndərildi",
    "Trash" : "Zibil",
    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi",
    "Actions" : "İşlər"
},
"nplurals=2; plural=(n != 1);");
